==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/FAILURECOSTID_TYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FAILURECOSTID_TYPE complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FAILURECOSTID_TYPE">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETCLASSDEFINITIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILUREMODECOSTTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FAILURECOSTID_TYPE", propOrder = {
    "organizationid",
    "assetclassdefinitionid",
    "failuremodecosttype"
})
public class FAILURECOSTID_TYPE {

    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "ASSETCLASSDEFINITIONID", required = true)
    protected STANDARDENTITYID_Type assetclassdefinitionid;
    @XmlElement(name = "FAILUREMODECOSTTYPE", required = true)
    protected USERDEFINEDCODEID_Type failuremodecosttype;

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété assetclassdefinitionid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getASSETCLASSDEFINITIONID() {
        return assetclassdefinitionid;
    }

    /**
     * Définit la valeur de la propriété assetclassdefinitionid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setASSETCLASSDEFINITIONID(STANDARDENTITYID_Type value) {
        this.assetclassdefinitionid = value;
    }

    /**
     * Obtient la valeur de la propriété failuremodecosttype.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getFAILUREMODECOSTTYPE() {
        return failuremodecosttype;
    }

    /**
     * Définit la valeur de la propriété failuremodecosttype.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setFAILUREMODECOSTTYPE(USERDEFINEDCODEID_Type value) {
        this.failuremodecosttype = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/FAILURECOSTID_TYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FAILURECOSTID_TYPE complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FAILURECOSTID_TYPE">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETCLASSDEFINITIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FAILUREMODECOSTTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FAILURECOSTID_TYPE", propOrder = {
    "organizationid",
    "assetclassdefinitionid",
    "failuremodecosttype"
})
public class FAILURECOSTID_TYPE {

    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "ASSETCLASSDEFINITIONID", required = true)
    protected STANDARDENTITYID_Type assetclassdefinitionid;
    @XmlElement(name = "FAILUREMODECOSTTYPE", required = true)
    protected USERDEFINEDCODEID_Type failuremodecosttype;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the assetclassdefinitionid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getASSETCLASSDEFINITIONID() {
        return assetclassdefinitionid;
    }

    /**
     * Sets the value of the assetclassdefinitionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setASSETCLASSDEFINITIONID(STANDARDENTITYID_Type value) {
        this.assetclassdefinitionid = value;
    }

    /**
     * Gets the value of the failuremodecosttype property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getFAILUREMODECOSTTYPE() {
        return failuremodecosttype;
    }

    /**
     * Sets the value of the failuremodecosttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setFAILUREMODECOSTTYPE(USERDEFINEDCODEID_Type value) {
        this.failuremodecosttype = value;
    }

}
